@@ -6,12 +6,13 @@ use Type::Library -base, -declare => qw( Uri Iri Namespace NamespaceMap );
 use Types::Standard qw( HashRef InstanceOf );
 use Types::URI qw();
 
+my $HalUri     = InstanceOf['Data::HAL::URI'];
 my $AtteanIRI  = InstanceOf['Attean::IRI'];
 my $TrineNS    = InstanceOf['RDF::Trine::Namespace'];
 my $TrineNSMap = InstanceOf['RDF::Trine::NamespaceMap'];
 my $TrineNode  = InstanceOf['RDF::Trine::Node::Resource'];
 
-our $VERSION = '1.09_02';
+our $VERSION = '1.09_03';
 
 =head1 NAME
 
@@ -93,6 +94,7 @@ __PACKAGE__->add_type(
 	coercion   => [
 		Iri->coercibles ,=> q{ "URI::Namespace"->new($_) },
 		$AtteanIRI      ,=> q{ "URI::Namespace"->new($_->as_string) },
+		$HalUri         ,=> q{ "URI::Namespace"->new($_->as_string) },
       $TrineNode      ,=> q{ "URI::Namespace"->new($_->as_string) },
       $TrineNS        ,=> q{ "URI::Namespace"->new($_->as_string) },
 	],
